==> eam-wshub-proxyclient-11.6-2-sources.jar: net/datastream/schemas/mp_results/mp7336_001/AdditionalWOEquipDetails.java <==

package net.datastream.schemas.mp_results.mp7336_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.DEPARTMENTID_Type;
import net.datastream.schemas.mp_fields.LOCATIONID_Type;
import net.datastream.schemas.mp_fields.PERSONID_Type;
import org.openapplications.oagis_segments.DATETIME;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LOCATIONID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASSIGNEDTO" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ISWARRANTYACTIVE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LASTMETERREADING" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DORMANTSTART" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DORMANTEND" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LOCATIONSAFETY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DEPARTMENTID" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "locationid",
    "assignedto",
    "iswarrantyactive",
    "lastmeterreading",
    "dormantstart",
    "dormantend",
    "locationsafety",
    "departmentid"
})
@XmlRootElement(name = "AdditionalWOEquipDetails")
public class AdditionalWOEquipDetails {

    @XmlElement(name = "LOCATIONID", namespace = "http://schemas.datastream.net/MP_fields")
    protected LOCATIONID_Type locationid;
    @XmlElement(name = "ASSIGNEDTO", namespace = "http://schemas.datastream.net/MP_fields")
    protected PERSONID_Type assignedto;
    @XmlElement(name = "ISWARRANTYACTIVE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String iswarrantyactive;
    @XmlElement(name = "LASTMETERREADING", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY lastmeterreading;
    @XmlElement(name = "DORMANTSTART", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME dormantstart;
    @XmlElement(name = "DORMANTEND", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME dormantend;
    @XmlElement(name = "LOCATIONSAFETY", namespace = "http://schemas.datastream.net/MP_fields")
    protected String locationsafety;
    @XmlElement(name = "DEPARTMENTID", namespace = "http://schemas.datastream.net/MP_fields")
    protected DEPARTMENTID_Type departmentid;

    /**
     * Obtient la valeur de la propriété locationid.
     * 
     * @return
     *     possible object is
     *     {@link LOCATIONID_Type }
     *     
     */
    public LOCATIONID_Type getLOCATIONID() {
        return locationid;
    }

    /**
     * Définit la valeur de la propriété locationid.
     * 
     * @param value
     *     allowed object is
     *     {@link LOCATIONID_Type }
     *     
     */
    public void setLOCATIONID(LOCATIONID_Type value) {
        this.locationid = value;
    }

    /**
     * Obtient la valeur de la propriété assignedto.
     * 
     * @return
     *     possible object is
     *     {@link PERSONID_Type }
     *     
     */
    public PERSONID_Type getASSIGNEDTO() {
        return assignedto;
    }

    /**
     * Définit la valeur de la propriété assignedto.
     * 
     * @param value
     *     allowed object is
     *     {@link PERSONID_Type }
     *     
     */
    public void setASSIGNEDTO(PERSONID_Type value) {
        this.assignedto = value;
    }

    /**
     * Obtient la valeur de la propriété iswarrantyactive.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getISWARRANTYACTIVE() {
        return iswarrantyactive;
    }

    /**
     * Définit la valeur de la propriété iswarrantyactive.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setISWARRANTYACTIVE(String value) {
        this.iswarrantyactive = value;
    }

    /**
     * Obtient la valeur de la propriété lastmeterreading.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getLASTMETERREADING() {
        return lastmeterreading;
    }

    /**
     * Définit la valeur de la propriété lastmeterreading.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setLASTMETERREADING(QUANTITY value) {
        this.lastmeterreading = value;
    }

    /**
     * Obtient la valeur de la propriété dormantstart.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getDORMANTSTART() {
        return dormantstart;
    }

    /**
     * Définit la valeur de la propriété dormantstart.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setDORMANTSTART(DATETIME value) {
        this.dormantstart = value;
    }

    /**
     * Obtient la valeur de la propriété dormantend.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getDORMANTEND() {
        return dormantend;
    }

    /**
     * Définit la valeur de la propriété dormantend.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setDORMANTEND(DATETIME value) {
        this.dormantend = value;
    }

    /**
     * Obtient la valeur de la propriété locationsafety.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLOCATIONSAFETY() {
        return locationsafety;
    }

    /**
     * Définit la valeur de la propriété locationsafety.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLOCATIONSAFETY(String value) {
        this.locationsafety = value;
    }

    /**
     * Obtient la valeur de la propriété departmentid.
     * 
     * @return
     *     possible object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public DEPARTMENTID_Type getDEPARTMENTID() {
        return departmentid;
    }

    /**
     * Définit la valeur de la propriété departmentid.
     * 
     * @param value
     *     allowed object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public void setDEPARTMENTID(DEPARTMENTID_Type value) {
        this.departmentid = value;
    }

}

==> eam-wshub-proxyclient-11.7-2-sources.jar: net/datastream/schemas/mp_results/mp7336_001/AdditionalWOEquipDetails.java <==

package net.datastream.schemas.mp_results.mp7336_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.DEPARTMENTID_Type;
import net.datastream.schemas.mp_fields.LOCATIONID_Type;
import net.datastream.schemas.mp_fields.PERSONID_Type;
import org.openapplications.oagis_segments.DATETIME;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LOCATIONID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASSIGNEDTO" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ISWARRANTYACTIVE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LASTMETERREADING" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DORMANTSTART" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DORMANTEND" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LOCATIONSAFETY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DEPARTMENTID" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "locationid",
    "assignedto",
    "iswarrantyactive",
    "lastmeterreading",
    "dormantstart",
    "dormantend",
    "locationsafety",
    "departmentid"
})
@XmlRootElement(name = "AdditionalWOEquipDetails")
public class AdditionalWOEquipDetails {

    @XmlElement(name = "LOCATIONID", namespace = "http://schemas.datastream.net/MP_fields")
    protected LOCATIONID_Type locationid;
    @XmlElement(name = "ASSIGNEDTO", namespace = "http://schemas.datastream.net/MP_fields")
    protected PERSONID_Type assignedto;
    @XmlElement(name = "ISWARRANTYACTIVE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String iswarrantyactive;
    @XmlElement(name = "LASTMETERREADING", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY lastmeterreading;
    @XmlElement(name = "DORMANTSTART", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME dormantstart;
    @XmlElement(name = "DORMANTEND", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME dormantend;
    @XmlElement(name = "LOCATIONSAFETY", namespace = "http://schemas.datastream.net/MP_fields")
    protected String locationsafety;
    @XmlElement(name = "DEPARTMENTID", namespace = "http://schemas.datastream.net/MP_fields")
    protected DEPARTMENTID_Type departmentid;

    /**
     * Gets the value of the locationid property.
     * 
     * @return
     *     possible object is
     *     {@link LOCATIONID_Type }
     *     
     */
    public LOCATIONID_Type getLOCATIONID() {
        return locationid;
    }

    /**
     * Sets the value of the locationid property.
     * 
     * @param value
     *     allowed object is
     *     {@link LOCATIONID_Type }
     *     
     */
    public void setLOCATIONID(LOCATIONID_Type value) {
        this.locationid = value;
    }

    /**
     * Gets the value of the assignedto property.
     * 
     * @return
     *     possible object is
     *     {@link PERSONID_Type }
     *     
     */
    public PERSONID_Type getASSIGNEDTO() {
        return assignedto;
    }

    /**
     * Sets the value of the assignedto property.
     * 
     * @param value
     *     allowed object is
     *     {@link PERSONID_Type }
     *     
     */
    public void setASSIGNEDTO(PERSONID_Type value) {
        this.assignedto = value;
    }

    /**
     * Gets the value of the iswarrantyactive property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getISWARRANTYACTIVE() {
        return iswarrantyactive;
    }

    /**
     * Sets the value of the iswarrantyactive property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setISWARRANTYACTIVE(String value) {
        this.iswarrantyactive = value;
    }

    /**
     * Gets the value of the lastmeterreading property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getLASTMETERREADING() {
        return lastmeterreading;
    }

    /**
     * Sets the value of the lastmeterreading property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setLASTMETERREADING(QUANTITY value) {
        this.lastmeterreading = value;
    }

    /**
     * Gets the value of the dormantstart property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getDORMANTSTART() {
        return dormantstart;
    }

    /**
     * Sets the value of the dormantstart property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setDORMANTSTART(DATETIME value) {
        this.dormantstart = value;
    }

    /**
     * Gets the value of the dormantend property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getDORMANTEND() {
        return dormantend;
    }

    /**
     * Sets the value of the dormantend property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setDORMANTEND(DATETIME value) {
        this.dormantend = value;
    }

    /**
     * Gets the value of the locationsafety property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLOCATIONSAFETY() {
        return locationsafety;
    }

    /**
     * Sets the value of the locationsafety property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLOCATIONSAFETY(String value) {
        this.locationsafety = value;
    }

    /**
     * Gets the value of the departmentid property.
     * 
     * @return
     *     possible object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public DEPARTMENTID_Type getDEPARTMENTID() {
        return departmentid;
    }

    /**
     * Sets the value of the departmentid property.
     * 
     * @param value
     *     allowed object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public void setDEPARTMENTID(DEPARTMENTID_Type value) {
        this.departmentid = value;
    }

}
